package lcsb.mapviewer.converter.model.sbgnaf.processors;

import lcsb.mapviewer.model.graphics.PolylineData;
import org.sbgn.bindings.Arc;

import java.awt.geom.Point2D;

public abstract class Processor<T> implements Comparable<Processor> {
  /**
   * Merge the given entity appropriately into the MINERVA data model.
   */
  public abstract void process();

  /**
   *
   * The smaller the priority number of a process the higher its priority.
   * E.g. a process with priority 0 will be executed before a process with priority 1.
   *
   * Priority legend:
   * Stand-alone glyphs: 0
   * Logical operators: 5
   * Arcs: 10
   * Containers: 15
   *
   * @return The priority of the process.
   */
  public abstract Integer getPriority();

  @Override
  public int compareTo(Processor processor) {
    return processor.getPriority().compareTo(this.getPriority());
  }

  /**
   * Transform arc coordinates into a polyline.
   *
   * @param arc The given arc.
   * @return The polyline representation of the arc.
   */
  protected PolylineData arc2PolylineData(Arc arc) {
    PolylineData polylineData = new PolylineData();
    if (arc.getStart() != null) {
      polylineData.addPoint(new Point2D.Float(arc.getStart().getX(), arc.getStart().getY()));
    }
    arc.getNext().forEach(next -> polylineData.addPoint(new Point2D.Float(next.getX(), next.getY())));
    if (arc.getEnd() != null) {
      polylineData.addPoint(new Point2D.Float(arc.getEnd().getX(), arc.getEnd().getY()));
    }
    return polylineData;
  }
}
