package lcsb.mapviewer.converter.model.sbgnaf.processors.containerNodes;

import lcsb.mapviewer.model.map.compartment.SquareCompartment;
import lcsb.mapviewer.model.map.model.Model;
import lcsb.mapviewer.model.map.species.Element;
import org.sbgn.GlyphClazz;
import org.sbgn.bindings.Glyph;
import org.sbgn.bindings.Sbgn;

public class CompartmentProcessor extends ContainerNodeProcessor {

  private Glyph glyph;
  private Model model;
  private Sbgn sbgnData;

  public CompartmentProcessor(Glyph glyph, Model model, Sbgn sbgnData) {
    super(GlyphClazz.COMPARTMENT);
    this.glyph = glyph;
    this.model = model;
    this.sbgnData = sbgnData;
  }

  @Override
  public void process() {
    SquareCompartment compartment = new SquareCompartment(glyph.getId());
    compartment.setZ(0);
    mapGlyphNameToElement(glyph, compartment);
    mapGlyphBBoxToElement(glyph, compartment);

    sbgnData
        .getMap()
        .getGlyph()
        .stream()
        .filter(g -> g.getCompartmentRef() != null)
        .filter(g -> ((Glyph) g.getCompartmentRef()).getId().equals(compartment.getElementId()))
        .map(Glyph::getId)
        // module is already populated because of low compartment priority
        .map(model::getElementByElementId)
        .map(Element.class::cast)
        .forEach(compartment::addElement);
    model.addElement(compartment);
  }
}
