package lcsb.mapviewer.converter.model.sbgnaf.processors.modulatingArcs;

import lcsb.mapviewer.converter.model.sbgnaf.processors.ArcProcessor;
import lcsb.mapviewer.model.graphics.PolylineData;
import lcsb.mapviewer.model.map.model.Model;
import lcsb.mapviewer.model.map.reaction.*;
import org.sbgn.ArcClazz;
import org.sbgn.bindings.Arc;
import org.sbgn.bindings.Glyph;

abstract class ModulatingArcProcessor extends ArcProcessor {

  private Arc arc;
  private Model model;

  ModulatingArcProcessor(ArcClazz arcClazz, Arc arc, Model model) {
    super(arcClazz);
    this.arc = arc;
    this.model = model;
  }

  Reaction createGenericReaction() {
    Glyph sourceGlyph = (Glyph) arc.getSource();
    Glyph targetGlyph = (Glyph) arc.getTarget();
    PolylineData line = arc2PolylineData(arc);
    Product product = new Product(model.getElementByElementId(targetGlyph.getId()));
    Reaction reaction = model.getReactionByReactionId(sourceGlyph.getId());
    if (reaction == null) { // is non-null if created by LogicalOperatorProcessor
      reaction = new Reaction(arc.getId());
      Reactant reactant = new Reactant(model.getElementByElementId(sourceGlyph.getId()));
      reaction.addReactant(reactant);
    } else { // remove placeholder reaction
      model.removeReaction(reaction);
    }
    reaction.getOperators().get(0).addOutput(product);
    reaction.addProduct(product);
    reaction.setLine(line);
    reaction.getNodes().forEach(node -> node.setLine(line));
    reaction.setZ(0);
    return reaction;
  }
}
